==> RSTouchscreenNG-0.92.2.zip: RSTouchscreenNG/projects/pages/src/lib/params.component.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from '@angular/core';
import {RSUIHelper} from "front-ui";
import {PrinterState, PrintersState, PrinterAction} from "binding";
import {select} from '@angular-redux/store';
import {Observable, SubscriptionLike} from 'rxjs';
import {Router} from "@angular/router";

@Component({
    selector: 'rs-params-component',
    template: `
      <rs-page>
        <rs-side>
          <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-sideicon *ngIf="printer?.printing" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-sideicon title="<?php _('Temp.') ?>" icon="rs rs-chart" link="/temperatures"></rs-sideicon>
        </rs-side>
        <main>
          <rs-headline><i class="rs rs-params"></i> {{tPrinterStatus}}</rs-headline>
          <div class="content-h1 iconlist" style="padding: 0;" *ngIf="printer" rsDrag>

            <div class="button-icon sep-icon" *ngFor="let p of printer.extruders;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setExtruderTemp(idx)">
                <i class="rs rs-extruder fw"></i>
                <div class="multiline">
                  <span [class.strong]="idx==printer.activeExtruderId">{{printerAction.extruderName(printer.slug, idx)}}</span><br>
                  {{p | tempFull:1}}
                </div>
              </rs-button>
            </div>

            <div class="button-icon sep-icon" *ngFor="let p of printer.heatedBeds;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setBedTemp(idx)">
                <i class="rs rs-heated-bed fw"></i>
                <div class="multiline"><?php _('Bed') ?><br>
                  {{p | tempFull:1}}
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngFor="let p of printer.heatedChambers;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setChamberTemp(idx)">
                <i class="rs rs-chamber fw"></i>
                <div class="multiline"><?php _('Chamber') ?><br>
                  {{p | tempFull:1}}
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngFor="let p of printer.fans;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setFan(idx)">
                <i class="rs rs-fan fw"></i>
                <div class="multiline"><?php _('Fan') ?> {{idx+1}}<br>
                  <div *ngIf="p.on">{{p.percent | fixed:0}}%</div>
                  <div *ngIf="!p.on"><?php _('Off') ?></div>
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setSpeed()">
                <i class="rs rs-speed fw"></i>
                <div class="multiline"><?php _('Speed') ?><br>
                  {{printer.speedMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setFlow()">
                <i class="rs rs-flow fw"></i>
                <div class="multiline"><?php _('Flow') ?><br>
                  {{printer.flowMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.toggleCaseLights(printer.slug)">
                <i class="rs rs-light fw"></i> <?php _('Light On/Off') ?> </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngIf="printer?.config?.general?.softwarePower">
              <rs-button class="secondary outline full" (hit)="printerAction.power(printer.slug)">
                <i class="fa fa-power-off fw"></i> <?php _('Power On/Off') ?>&nbsp;
              </rs-button>
            </div>
            <div *rsIfPrinting="false" class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.preheat(printer.slug, 2)">
                <i class="rs rs-temperature fw"></i> <?php _('Preheat Active') ?>
              </rs-button>
            </div>
            <div *rsIfPrinting="false" class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.preheat(printer.slug, 1)">
                <i class="rs rs-temperature fw"></i> <?php _('Preheat All') ?>
              </rs-button>
            </div>
            <div *rsIfPrinting="false" class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.cooldown(printer.slug)">
                <i class="rs rs-temperature fw"></i> <?php _('Cooldown') ?>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="goBabystep()">
                <i class="rs rs-move-z fw"></i> <?php _('Babystep') ?>
              </rs-button>
            </div>
          </div>
        </main>
      </rs-page>
    `
})

export class ParamsComponent implements OnDestroy {
    printer: PrinterState;
    @select('printers') printers$: Observable<PrintersState>;
    tPrinterStatus = "<?php _('Printer Status') ?>";

    private printersSubscription: SubscriptionLike;

    constructor(public ui: RSUIHelper,
                public printerAction: PrinterAction,
                public router: Router) {
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (p.active) {
                this.printer = p.printers[p.active];
            } else {
                this.printer = undefined;
            }
        });
    }

    ngOnDestroy(): void {
        this.printersSubscription.unsubscribe();
    }

    goBabystep(): void {
        this.router.navigateByUrl('/babystep');
    }
}

==> RSTouchscreenNG-0.94.3.zip: RSTouchscreenNG/projects/pages/src/lib/params.component.ts <==
/* (C) 2016-2020 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {RSUIHelper} from "front-ui";
import {PrinterState, PrintersState, PrinterAction} from "binding";
import {select} from "@angular-redux/store";
import {Observable, SubscriptionLike} from "rxjs";
import {Router} from "@angular/router";

@Component({
  selector: "rs-params-component",
  template: `
      <rs-page>
        <rs-side>
          <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
        </rs-side>
        <rs-side *rsIfConnected="true">
          <rs-sideicon *ngIf="printer?.printing" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
          <rs-sideicon *rsIfPrinting="false" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-sideicon title="<?php _('Temp.') ?>" icon="rs rs-chart" link="/temperatures"></rs-sideicon>
        </rs-side>
        <main>
          <rs-headline><i class="rs rs-params"></i> {{tPrinterStatus}}</rs-headline>
          <div class="content-h1 iconlist" style="padding: 0;" *ngIf="printer && printer.online === 1" rsDrag>

            <ng-container *ngFor="let p of printer.extruders;let idx = index">
              <div class="button-icon sep-icon" *ngIf="printerAction.toolSupportsTemperatures(printer.slug, idx)">
                <rs-button class="secondary outline full" (hit)="ui.setExtruderTemp(idx)">
                  <i class="fw" [class]="printerAction.extruderIcon(printer.slug, idx)"></i>
                  <div class="multiline">
                    <span [class.strong]="idx==printer.activeExtruderId">{{printerAction.extruderName(printer.slug, idx)}}</span><br>
                    {{p | tempFull:1}}
                 </div>
                </rs-button>
              </div>
            </ng-container>

            <div class="button-icon sep-icon" *ngFor="let p of printer.heatedBeds;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setBedTemp(idx)">
                <i class="rs rs-heated-bed fw"></i>
                <div class="multiline"><?php _('Bed') ?><br>
                  {{p | tempFull:1}}
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngFor="let p of printer.heatedChambers;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setChamberTemp(idx)">
                <i class="rs rs-chamber fw"></i>
                <div class="multiline"><?php _('Chamber') ?><br>
                  {{p | tempFull:1}}
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngFor="let p of printer.fans;let idx = index">
              <rs-button class="secondary outline full" (hit)="ui.setFan(idx)">
                <i class="rs rs-fan fw"></i>
                <div class="multiline"><?php _('Fan') ?> {{idx+1}}<br>
                  <div *ngIf="p.on">{{p.percent | fixed:0}}%</div>
                  <div *ngIf="!p.on"><?php _('Off') ?></div>
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setSpeed()">
                <i class="rs rs-speed fw"></i>
                <div class="multiline"><?php _('Speed') ?><br>
                  {{printer.speedMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="ui.setFlow()">
                <i class="rs rs-flow fw"></i>
                <div class="multiline"><?php _('Flow') ?><br>
                  {{printer.flowMultiply}}%
                </div>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.toggleCaseLights(printer.slug)">
                <i class="rs rs-light fw"></i> <?php _('Light On/Off') ?> </rs-button>
            </div>
            <div class="button-icon sep-icon" *ngIf="printer?.config?.general?.softwarePower">
              <rs-button class="secondary outline full" (hit)="printerAction.power(printer.slug)">
                <i class="fa fa-power-off fw"></i> <?php _('Power On/Off') ?>&nbsp;
              </rs-button>
            </div>
            <div *rsIfPrinting="false" class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.preheat(printer.slug, 2)">
                <i class="rs rs-temperature fw"></i> <?php _('Preheat Active') ?>
              </rs-button>
            </div>
            <div *rsIfPrinting="false" class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.preheat(printer.slug, 1)">
                <i class="rs rs-temperature fw"></i> <?php _('Preheat All') ?>
              </rs-button>
            </div>
            <div *rsIfPrinting="false" class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="printerAction.cooldown(printer.slug)">
                <i class="rs rs-temperature fw"></i> <?php _('Cooldown') ?>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="goBabystep()">
                <i class="rs rs-move-z fw"></i> <?php _('Babystep') ?>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="goConsole()">
                <i class="rs rs-printer-commands fw"></i> <?php _('Console') ?>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="goMove()">
                <i class="rs rs-move-xy fw"></i> <?php _('Move') ?>
              </rs-button>
            </div>
            <div class="button-icon sep-icon">
              <rs-button class="secondary outline full" (hit)="goExtruder()">
                <i [class]="printerAction.extruderIcon(printer.slug,printer.activeExtruderId)+' fw'"></i> <?php _('Extrude') ?>
              </rs-button>
            </div>
          </div>
        </main>
      </rs-page>
    `
})

export class ParamsComponent implements OnDestroy {
  printer: PrinterState;
  @select("printers") printers$: Observable<PrintersState>;
  tPrinterStatus = "<?php _('Printer Status') ?>";

  private printersSubscription: SubscriptionLike;

  constructor(public ui: RSUIHelper,
              public printerAction: PrinterAction,
              public router: Router) {
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
    });
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
  }

  goBabystep(): void {
    this.router.navigateByUrl("/babystep");
  }

  goConsole(): void {
    this.router.navigateByUrl("/console");
  }

  goMove(): void {
    this.router.navigateByUrl("/move-tool");
  }

  goExtruder(): void {
    this.router.navigateByUrl("/move-e-tool");
  }

}
